generate_image_references: Generate govdown image references

View source: R/utility_functions.R

generate_image_referencesR Documentation

Generate govdown image references

Description

Converts image file names to a dataframe, with a field containing the original image name and corresponding govdown reference

Usage

generate_image_references(img_filenames)

Arguments

img_filenames

character vector of files to be referenced in govdown format (!!n). The filename must start and end with a number and have text in between (eg, "1 abcd 1.png")


best-practice-and-impact/govspeakr documentation built on April 24, 2023, 1:19 p.m.