View source: R/utility_functions.R
| generate_image_references | R Documentation |
Converts image file names to a dataframe, with a field containing the original image name and corresponding govdown reference
generate_image_references(img_filenames)
img_filenames |
character vector of files to be referenced in govdown format (!!n). The filename must start and end with a number and have text in between (eg, "1 abcd 1.png") |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.